@@ -9,7 +9,7 @@ __all__ = (
     "RouteModel", "RouteItemModel", "JourneyModel", "JourneyBunchModel", "JourneyBunchItemModel", "IntervalModel",
     "JourneyProgressModel", "CrewModel", "JourneyScheduleModel", "PermitModel", "VehicleModel", "PersonModel",
     "DurationModel", "DurationItemModel", "IntervalItemModel", "JourneyIntervalModel", "JourneyItemModel",
-    "RouteMetrics",
+    "RouteMetrics", "OrganizationModel", "SeatsRow",
 )
 
 from .dispatcher_models import (
@@ -29,6 +29,7 @@ from .sarmat_models import (
     DurationModel,
     IntervalItemModel,
     IntervalModel,
+    OrganizationModel,
     PersonModel,
 )
 from .traffic_management_models import (
@@ -45,5 +46,6 @@ from .traffic_management_models import (
 from .vehicle_models import (
     CrewModel,
     PermitModel,
+    SeatsRow,
     VehicleModel,
 )
