@@ -50,6 +50,9 @@ class PriceCalculationStep(PriceCalculation):
     steps: dict[int, float]     # маппинг стоимости на расстояние
     calc_type: CalculationType = CalculationType.STEP
 
+    def __post_init__(self):
+        self.steps = {int(key): round(val, 2) for key, val in self.steps.items()}
+
 
 class PriceCalculator(ABC):
     """Калькулятор стоимости проезда."""
